@@ -131,8 +131,8 @@ def mod_root(a, p):
         while h != 1:
             h = (h * h) % p
             m += 1
-        h = 0
-        h.setbit(r - m - 1)
+        h = gmpy.mpz(0)
+        h = h.setbit(r - m - 1)
         t = pow(y, h, p)
         y = (t * t) % p
         r = m
@@ -478,7 +478,7 @@ class PubKey(object):
     def __str__(self):
         return self.to_string(SER_COMPACT)
     def __repr__(self):
-        return "<PubKey %s>" % unicode(self)
+        return "<PubKey %s>" % self
 
 class PrivKey(object):
     """ A secret exponent """
